@@ -8,16 +8,28 @@
 
 class QGraphicsScene;
 
+class ReversiItem;
+
+class PixmapsFactory
+{
+public:
+    PixmapsFactory();
+private:
+    QPixmap chipPixmaps_[13];
+
+    friend class ReversiItem;
+}; //class PixmapsFactory
+
 class ReversiItem : public QGraphicsPixmapItem
 {
 public:
-    ReversiItem(QGraphicsScene *scene);
+    ReversiItem(QGraphicsScene *scene, PixmapsFactory *pixmapsFactory);
+    static void initPixmaps();
     void setColor(int c);
     int width() const {return pixmap().width();}
     int height() const {return pixmap().height();}
-
 private:
-    QPixmap chipPixmaps_[13];
+    PixmapsFactory *pixmapsFactory_;
 };
 
 #endif // REVERSIITEM_H
