@@ -1,39 +1,44 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QWidget>
 #include <QTimer>
+#include <QPixmap>
 
 #include "reversiscene.h"
 #include "reversiitem.h"
 #include "reversidefs.h"
 #include "reversigame.h"
+#include "pixmaps/EmptyCell.xpm"
 
-ReversiScene::ReversiScene(ReversiGame &reversiGame, QWidget *mainWin):
+ReversiScene::ReversiScene(ReversiGame &reversiGame):
         reversiGame_(reversiGame), cellWidth_(0), cellHeight_(0),
         isNetworkMode_(false)
 {
+    //temporary pixmap for calculating width and heigh of cell
+    QPixmap p(EmptyCell_xpm);
+    cellWidth_ = p.width();
+    cellHeight_ = p.height();
+
+    pixmapsFactory_ = new PixmapsFactory();
+
     animTimer_ = new QTimer(this);
-
-    for (unsigned i = 0; i < FIELDSIZE; ++i)
-        for(unsigned j = 0; j < FIELDSIZE; j++)
+    for (unsigned i = 0, x = 0; i < FIELDSIZE; ++i, x += cellWidth_)
+        for(unsigned j = 0, y = 0; j < FIELDSIZE; j++, y += cellHeight_)
         {
-            ReversiItem *ri = new ReversiItem(this);
-            if (!cellWidth_) cellWidth_ = ri->width();
-            if (!cellHeight_) cellHeight_ = ri->height();
-            ri->setPos(i * cellWidth_, j * cellHeight_);
+            ReversiItem *ri = new ReversiItem(this, pixmapsFactory_);
+            ri->setPos(x, y);
         }
-
     fieldWidth_ = FIELDSIZE * cellWidth_;
     fieldHeight_ = FIELDSIZE * cellHeight_;
 
     connect(&reversiGame_, SIGNAL(stepComplete()), SLOT(slotStepComplete()));
     connect(&reversiGame_, SIGNAL(newGame(bool)), SLOT(slotNewGame(bool)));
     connect(animTimer_, SIGNAL(timeout()), SLOT(slotAnimationStep()));
-    //mainWin->connect(this, SIGNAL(stepUnavailable()), mainWin, SLOT(stepUnavailable()));
 }
 
 ReversiScene::~ReversiScene()
 {
     delete animTimer_;
+    delete pixmapsFactory_;
 }
 
 void ReversiScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
