@@ -5,15 +5,17 @@
 
 #include "reversidefs.h"
 
-class ReversiGame;
 class QWidget;
 class QTimer;
 
+class ReversiGame;
+class PixmapsFactory;
+
 class ReversiScene : public QGraphicsScene
 {
     Q_OBJECT
 public:
-    ReversiScene(ReversiGame &reversiGame, QWidget *mainWin);
+    ReversiScene(ReversiGame &reversiGame);
     ~ReversiScene();
     int fieldWidth() const { return fieldWidth_; }
     int fieldHeight() const { return fieldHeight_; }
@@ -51,6 +53,7 @@ private:
     int animDirection_;     // 1 - from white to black, -1 - from black to white
     int animFirstCell_;     // first animated cell
     int animLastCell_;      // last animated cell
+    PixmapsFactory *pixmapsFactory_;
 };
 
 #endif // REVERSISCENE_H
